;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "kaolin-themes" "1.7.5"
  "A set of eye pleasing themes."
  '((emacs      "25.1")
    (autothemer "0.2.2")
    (cl-lib     "0.6"))
  :url "https://github.com/ogdenwebb/emacs-kaolin-themes"
  :commit "eaf70548fb0095b4041a9e82cd3b4dff6d3ba48d"
  :revdesc "eaf70548fb00"
  :keywords '("dark" "light" "teal" "blue" "violet" "purple" "brown" "theme" "faces")
  :authors '(("Ogden Webb" . "ogdenwebb@gmail.com"))
  :maintainers '(("Ogden Webb" . "ogdenwebb@gmail.com")))
